#include <iostream>
#include <vector>
#include <string>
#include <set>
#include <algorithm>
#include <array>

using namespace std;

typedef long long ll;
typedef long double ld;

ll gcd(ll a, ll b) {
	if (b == 0)
		return a;
	return gcd(b, a % b);
}
struct Point {
	ll x = 0, y = 0;
	Point() = default;
	Point(ll a, ll b) {
		x = a, y = b;
	}
};
struct DoublePoint {
	ld x = 0, y = 0;
	DoublePoint() = default;
	DoublePoint(ll a, ll b) {
		x = a;
		y = b;
	}
	DoublePoint(Point p0) {
		x = p0.x, y = p0.y;
	}
};
struct Line {
	ll a, b, c;
	Line() = default;
	Line(ll x, ll y, ll z) {
		a = x, b = y, c = z;
		norm();
	}
	Line(Point A, Point B) {
		a = A.y - B.y;
		b = B.x - A.x;
		c = A.x * B.y - B.x * A.y;
		norm();
	}
	void norm() {
		ll g = gcd(abs(a), gcd(abs(b), abs(c)));
		a /= g;
		b /= g;
		c /= g;
		if (a < 0)
			a *= -1, b *= -1, c *= -1;
	}
};
struct Vec {
	ll x = 0, y = 0;
	Vec() = default;
	Vec(ll a, ll b) {
		x = a, y = b;
	}
	Vec(Point s, Point e) {
		x = e.x - s.x;
		y = e.y - s.y;
	}
	ll operator*(Vec b) {
		return x * b.x + y * b.y;
	}
};

ll DistPoints2(Point a, Point b) {
	return (a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y);
}
ld DistPointLine(Point x, Line l) {
	ld ch = (x.x * l.a + x.y * l.b + l.c);
	return ch * ch / (l.a * l.a + l.b * l.b);
}
ld DistPointOtr(Point x, Point a, Point b) {
	if (Vec(a, b) * Vec(a, x) <= 0)
		return DistPoints2(a, x);
	if (Vec(b, a) * Vec(b, x) <= 0)
		return DistPoints2(b, x);
	return DistPointLine(x, Line(a, b));
}

int IsIntersect(Line a, Line b) {
	if (a.a == b.a && a.b == b.b && a.c == b.c)
		return 2;
	if (a.a == 0 || b.a == 0 || a.b == 0 || b.b == 0) {
		return !(a.a == b.a && a.b == b.b);
	}
	if (a.a >= b.a && a.b >= b.b) {
		if (a.a % b.a == 0 && a.b % b.b == 0) {
			ll ka = a.a / b.a, kb = a.b / b.b;
			if (ka == kb)
				return 0;
		}
	}
	if (b.a >= a.a && b.b >= a.b) {
		if (b.a % a.a == 0 && b.b % a.b == 0) {
			ll ka = b.a / a.a, kb = b.b / a.b;
			if (ka == kb)
				return 0;
		}
	}
	return 1;
}

DoublePoint GetIntersect(Line a, Line b) {
	double zn = a.a * b.b - b.a * a.b;
	DoublePoint ans;
	ans.x = (a.b * b.c - b.b * a.c) / zn;
	ans.y = (b.a * a.c - a.a * b.c) / zn;
	return ans;
}

bool ProjectionsOtr(DoublePoint p, Point a, Point b) {
	return min(a.x, b.x) <= p.x && p.x <= max(a.x, b.x) && min(a.y, b.y) <= p.y && p.y <= max(a.y, b.y);
}

ld DistOtrs(Point a, Point b, Point c, Point d) {
	int k = IsIntersect(Line(a, b), Line(c, d));
	if (k == 1) {
		DoublePoint p = GetIntersect(Line(a, b), Line(c, d));
		if (ProjectionsOtr(p, a, b) && ProjectionsOtr(p, c, d))
			return 0;
	}
	if (k == 2) {
		if (ProjectionsOtr(a, c, d) || ProjectionsOtr(b, c, d))
			return 0;
	}
	return min(min(DistPointOtr(a, c, d), DistPointOtr(b, c, d)), min(DistPointOtr(c, a, b), DistPointOtr(d, a, b)));
}

ll GetLen(Point a, Point b) {
	return (b.x - a.x) * (b.x - a.x) + (b.y - a.y) * (b.y - a.y);
}

ld eps = 1e-3;

int main() {
	cin.tie(0);
	ios_base::sync_with_stdio(0);
	int m;
	cin >> m;
	vector<pair<Point, Point>>arr(m);
	for (auto& i : arr) {
		cin >> i.first.x >> i.first.y >> i.second.x >> i.second.y;
	}
	int ans = 0;
	for (int i = 0; i < m; i++) {
		for (int j = i + 1; j < m; j++) {
			for (int k = j + 1; k < m; k++) {
				ld dij = DistOtrs(arr[i].first, arr[i].second, arr[j].first, arr[j].second),
					djk = DistOtrs(arr[j].first, arr[j].second, arr[k].first, arr[k].second),
					dik = DistOtrs(arr[i].first, arr[i].second, arr[k].first, arr[k].second);
				ll di = GetLen(arr[i].first, arr[i].second),
					dj = GetLen(arr[j].first, arr[j].second),
					dk = GetLen(arr[k].first, arr[k].second);
				if (dij - dk <= eps || dik - dj <= eps || djk - di <= eps)
					ans++;
			}
		}
	}
	cout << ans;
	return 0;
}