﻿#include <iostream>
#include <fstream>
#include <sstream>
#include <iomanip>

#include <algorithm>
#include <cmath>

#include <chrono>
#include <random>

#include <unordered_map>
#include <unordered_set>
#include <functional>
#include <vector>
#include <string>
#include <array>
#include <tuple>
#include <deque>
#include <queue>
#include <stack>
#include <list>
#include <set>
#include <map>

using namespace std;
using namespace chrono;

using ll = long long;
using ull = unsigned long long;
using ld = long double;

constexpr ll INF = 1e15;
constexpr ld EPS = 1e-9L;

mt19937 rnd(0);


//
//struct Node {
//    ll a, b;
//    ll ind;
//};
//
//bool cmp(Node a, Node b) {
//    if (a.a * b.b > a.b * b.a) {
//        return true;
//    }
//    return false;
//}

struct pt {
    ll x, y;
    pt(ll x, ll y) : x(x), y(y) {}
};

pt operator-(pt A, pt B) {
    return pt(A.x - B.x, A.y - B.y);
}

long double len(pt A) {
    return sqrtl(A.x * A.x + A.y * A.y);
}

long double len(pt a, pt b) {
    return len(a-b);
}

ll dot(pt A, pt B) {
    return A.x * B.x + A.y * B.y;
}

ll cross(pt A, pt B) {
    return A.x * B.y - A.y * B.x;
}

struct seg {
    pt a, b;
    seg(pt a, pt b) : a(a), b(b) {}
};

long double len(seg s) {
    return len(s.a, s.b);
}

bool bounding_box(ll l1, ll r1, ll l2, ll r2) {
    if (l1 > r1) swap(l1, r1);
    if (l2 > r2) swap(l2, r2);
    if (l1 > l2) {
        swap(l1, l2);
        swap(r1, r2);
    }
    return r1 > l2;
}

bool intersect(seg s1, seg s2) {
    return ((cross(s2.a-s2.b, s1.a-s2.b)*cross(s2.a-s2.b, s1.b-s2.b)<=0) && (cross(s1.a - s1.b, s2.a - s1.b) * cross(s1.a - s1.b, s2.b - s1.b) <= 0) && bounding_box(s1.a.x, s1.b.x, s2.a.x, s2.b.x) && bounding_box(s1.a.y, s1.b.y, s2.a.y, s2.b.y));
}

bool is_per_seg(seg s, pt c) {
    return dot(s.a - s.b, c) * dot(s.b - s.a, c) >= 0;
}

long double perp(seg s, pt c) {
    return dot(pt((s.a - s.b).y, -(s.a - s.b).x), c - s.b) / len(s);
}

long double dist(seg s, pt c) {
    if (is_per_seg(s, c))
        return perp(s, c);
    else
        return min(len(c, s.a), len(c, s.b));
}

long double dist(seg s1, seg s2) {
    if (intersect(s1, s2))
        return 0;
    else
        return min(min(dist(s1, s2.a), dist(s1, s2.b)), min(dist(s2, s1.a), dist(s2, s1.b)));
}


bool check(seg A, seg B, seg l) {
    return dist(A, B) <= len(l);
}

int main() {
    ios_base::sync_with_stdio(false);
    cout.tie(nullptr);
    cin.tie(nullptr);
    ll n, x, y;
    cin >> n;
    vector<seg> s;
    for (ll i = 0; i < n; i++) {
        cin >> x >> y;
        pt a(x, y);
        cin >> x >> y;
        pt b(x, y);
        s.push_back(seg(a, b));
    }
    ll cnt = 0;
    for (ll i = 0; i < n; i++) {
        for (ll j = i + 1; j < n; j++) {
            for (ll k = j + 1; k < n; k++) {
                if (check(s[i], s[j], s[k]) || check(s[i], s[k], s[j]) || check(s[j], s[k], s[i]))
                    cnt++;
            }
        }
    }
    cout << cnt;
}